==> vardoc-4.0.x-dev.tar.gz: vardoc/README.md <==
[![Vardot](https://circleci.com/gh/Vardot/vardoc/tree/4.0.x.svg?style=shield)](https://app.circleci.com/pipelines/github/Vardot/vardoc/227/workflows/ed1021f5-59ad-4ae8-b0cb-377532a7e22d) Vardoc 4.0.10
# Vardoc: Knowledge Base System and Documentation Site

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Vardoc%20-%20No%20Padding.png)](https://www.drupal.org/project/vardoc)

## Built Using [Varbase](https://www.drupal.org/project/varbase)
This distribution is built using Varbase, the base distribution delivered
 to you by [Vardot](https://www.vardot.com).
Learn more about [Varbase](https://www.drupal.org/project/varbase) and how
 you can build your own distribution on top
 of Varbase here: [http://docs.varbase.vardot.com](http://docs.varbase.vardot.com)

## About Vardoc
Vardoc is a knowledge base system, a wiki system, and a documentation management
 system designed to host massive amount of content in a structured and
 easy-to-find format. Vardoc helps you build a connected organization,
 product, or knowledge area to allow everyone involved to find the answers
 they seek, and contribute their expertise in the knowledge base.

Think of it as a wiki site of your product, user manuals, or organizational
 processes. With easy structure, collaborative tools, and friendly design.

[![](https://www.drupal.org/files/project-images/vardoc-mockup.png)](https://www.drupal.org/project/vardoc)

Built on top of Varbase, the open source Drupal distribution, Vardoc provides
 powerful functional features such as editorial features, search function,
 taxonomy, user management, and customizable themes. It also delivers
 top-notch non-functional requirements such as enterprise security,
 fast performance, search engine optimization (SEO), accessibility
 compliance, and many more features.

[![](https://www.drupal.org/files/vardoc-mockup-2.jpg)](https://www.drupal.org/project/vardoc)

Our goal is to bring ease to you when writing and creating a documentation
 for your product, website, departmental processes, online manuals,
 or your enterprise as whole.

## Who Can Benefit From Vardoc?
* Product documentation sites.
* Agencies who want to document software.
* Documentation for Open Source products/projects.
* Organizations who want to document their processes.
* Online user manuals.

## Install or Try it Yourself
# [Try on Simplytest.me](https://simplytest.me/project/vardoc)

## Or install it via Composer:

# Install with Composer

To install the most recent stable release of Vardoc run this command:
```
composer create-project Vardot/vardoc-project:~4 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Vardoc 4.0.x run this command:
```
composer create-project vardot/vardoc-project:4.0.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

# [Install with Composer](https://github.com/Vardot/vardoc-project)

Built using [Varbase](https://www.drupal.org/project/varbase), the base
 distribution delivered to you by [Vardot](https://www.vardot.com)

This distribution is sponsored and developed by [Vardot](https://www.vardot.com).
Initial building, ongoing maintenance and development.


## [Automated Functional Testing](https://github.com/Vardot/vardoc/blob/4.0.x/tests/README.md)

## [Vardoc Gherkin features](https://github.com/Vardot/vardoc/blob/4.0.x/tests/features/vardoc/README.md)

## [Varbase Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Vardoc](https://github.com/Vardot/vardoc/blob/4.0.x/CHANGELOG.md)

## [General instructions on how to update Vardoc](https://github.com/Vardot/vardoc/blob/4.0.x/UPDATE.md)

==> vardoc-5.0.x-dev.tar.gz: vardoc/README.md <==
[![Vardot](https://circleci.com/gh/Vardot/vardoc/tree/5.0.x.svg?style=shield)](https://app.circleci.com/pipelines/github/Vardot/vardoc/166/workflows/42955edb-3d62-47a1-b277-33defddc59ad) Vardoc 5.0.0-rc1
# Vardoc: Knowledge Base System and Documentation Site

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Vardoc%20-%20No%20Padding.png)](https://www.drupal.org/project/vardoc)

## Built Using [Varbase](https://www.drupal.org/project/varbase)
This distribution is built using Varbase, the base distribution delivered
 to you by [Vardot](https://www.vardot.com).
Learn more about [Varbase](https://www.drupal.org/project/varbase) and how
 you can build your own distribution on top
 of Varbase here: [http://docs.varbase.vardot.com](http://docs.varbase.vardot.com)

## About Vardoc
Vardoc is a knowledge base system, a wiki system, and a documentation management
 system designed to host massive amount of content in a structured and
 easy-to-find format. Vardoc helps you build a connected organization,
 product, or knowledge area to allow everyone involved to find the answers
 they seek, and contribute their expertise in the knowledge base.

Think of it as a wiki site of your product, user manuals, or organizational
 processes. With easy structure, collaborative tools, and friendly design.

[![](https://www.drupal.org/files/project-images/vardoc-mockup.png)](https://www.drupal.org/project/vardoc)

Built on top of Varbase, the open source Drupal 9 distribution, Vardoc provides
 powerful functional features such as editorial features, search function,
 taxonomy, user management, and customizable themes. It also delivers
 top-notch non-functional requirements such as enterprise security,
 fast performance, search engine optimization (SEO), accessibility
 compliance, and many more features.

[![](https://www.drupal.org/files/vardoc-mockup-2.jpg)](https://www.drupal.org/project/vardoc)

Our goal is to bring ease to you when writing and creating a documentation
 for your product, website, departmental processes, online manuals,
 or your enterprise as whole.

## Who Can Benefit From Vardoc?
* Product documentation sites.
* Agencies who want to document software.
* Documentation for Open Source products/projects.
* Organizations who want to document their processes.
* Online user manuals.

## Install or Try it Yourself
# [Try on Simplytest.me](https://simplytest.me/project/vardoc)

## Or install it via Composer:

# Install with Composer

To install the most recent stable release of Vardoc 5.0.x run this command:
```
composer create-project Vardot/vardoc-project:5.0.0-beta1 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Vardoc 5.0.x run this command:
```
composer create-project vardot/vardoc-project:5.0.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

# [Install with Composer](https://github.com/Vardot/vardoc-project)

Built using [Varbase](https://www.drupal.org/project/varbase), the base
 distribution delivered to you by [Vardot](https://www.vardot.com)

This distribution is sponsored and developed by [Vardot](https://www.vardot.com).
Initial building, ongoing maintenance and development.


## [Automated Functional Testing](https://github.com/Vardot/vardoc/blob/5.0.x/tests/README.md)

## [Vardoc Gherkin features](https://github.com/Vardot/vardoc/blob/5.0.x/tests/features/vardoc/README.md)

## [Varbase Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Vardoc](https://github.com/Vardot/vardoc/blob/5.0.x/CHANGELOG.md)

## [General instructions on how to update Vardoc](https://github.com/Vardot/vardoc/blob/5.0.x/UPDATE.md)
